Language Detection
==================

.. note::

    This tutorial is available as an IPython notebook
    `here <https://github.com/huseinzol05/Malaya/tree/master/example/language-detection>`_.

.. include:: load-language-detection.rst
